#!/bin/bash

if [ -d "perfectring" ]
then
    echo "perfectring already exists."
    exit 1
fi

#Create directories: scenario.xml for all routing agents
for scen in perfectring; do
    for par in Pure_PerfectRing SLR_PerfectRing SLR_NoRing Pure_Ring SLR_Ring; do #_PerfectRing is expanded ring, _Ring is original ring
	for rng in `seq 0 9`; do
	    dir="${scen}/${par}/run${rng}"
	    mkdir -p $dir
	    cp scenario.xml ${dir}/scenario.xml
	    if [ $par = "Pure_PerfectRing" ]
	    then
		sed -i 's/PureFloodingRouting/PureFloodingPerfectRingRouting rangeBig_nm="1000000" rangeSmall_nm="830000"/g' ${dir}/scenario.xml
	    elif [ $par = "SLR_PerfectRing" ]
	    then
		sed -i 's/PureFloodingRouting/SLRPerfectRingRouting commRangeSetup_nm="830000" anchor1id="0" anchor2id="1" rangeBig_nm="1000000" rangeSmall_nm="830000"/g' ${dir}/scenario.xml
	    elif [ $par = "SLR_NoRing" ]
	    then
		sed -i 's/PureFloodingRouting/SLRRouting commRangeSetup_nm="800000" anchor1id="0" anchor2id="1"/g' ${dir}/scenario.xml
	    elif [ $par = "Pure_Ring" ]
	    then
		sed -i 's/PureFloodingRouting/PureFloodingRingRouting rangeBig_nm="1000000" rangeSmall_nm="830000"/g' ${dir}/scenario.xml
	    elif [ $par = "SLR_Ring" ]
	    then
		sed -i 's/PureFloodingRouting/SLRRingRouting commRangeSetup_nm="830000" anchor1id="0" anchor2id="1" rangeBig_nm="1000000" rangeSmall_nm="830000"/g' ${dir}/scenario.xml
	    fi
	done
    done
done


#Run bitsimulator

for scen in perfectring; do
    for par in SLR_PerfectRing; do
	for rng in 0; do 
	    dir="${scen}/${par}/run${rng}"
	    echo Running ${scen} ${par} with seed ${rng}
	    if [ $par = "SLR_PerfectRing" ] 
	    then
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList #&> /dev/null
	    fi
	    awk '$1 == "1" &&  $6=="1003"'  ${dir}/events.log > ${dir}/receivedata.log
	    awk '$1 == "0" &&  $7=="1003"'  ${dir}/events.log > ${dir}/senddata.log
	    awk '$1 == "0"'  ${dir}/events.log > ${dir}/allsend.log
	done
    done
done

for scen in perfectring; do
    for par in Pure_PerfectRing SLR_NoRing Pure_Ring SLR_Ring; do
	#beginpar
	for rng in 0; do #start with slr ring, not in parallel with others because need its deden and slr init
	    dir="${scen}/${par}/run${rng}"
	    echo Running ${scen} ${par} with seed ${rng}
	    if  [ $par = "Pure_PerfectRing" ] || [ $par = "Pure_Ring" ]
	    then
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList #&> /dev/null
	    elif  [ $par = "SLR_NoRing" ] || [ $par = "SLR_Ring" ]
	    then
		cp ${scen}/SLR_PerfectRing/run0/SLRPositions.log ${dir}/SLRPositions.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --loadSLRPositionsFromFile #&> /dev/null
	    fi
	    awk '$1 == "1" &&  $6=="1003"'  ${dir}/events.log > ${dir}/receivedata.log
	    awk '$1 == "0" &&  $7=="1003"'  ${dir}/events.log > ${dir}/senddata.log
	    awk '$1 == "0"'  ${dir}/events.log > ${dir}/allsend.log
	done
	#endpar
    done
done
#waitpar

for scen in perfectring; do
    for par in  Pure_PerfectRing SLR_PerfectRing SLR_NoRing Pure_Ring SLR_Ring; do
	#beginpar
	for rng in `seq 1 9`; do #start with slr ring, not in parallel with others because need its deden and slr init
	    dir="${scen}/${par}/run${rng}"
	    echo Running ${scen} ${par} with seed ${rng}
	    if  [ $par = "SLR_PerfectRing" ] || [ $par = "SLR_NoRing" ] || [ $par = "SLR_Ring" ]
	    then
		cp ${scen}/SLR_PerfectRing/run0/SLRPositions.log ${dir}/SLRPositions.log
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList --loadSLRPositionsFromFile #&> /dev/null
	    elif  [ $par = "Pure_PerfectRing" ] || [ $par = "Pure_Ring" ]
	    then
		time ./bitsimulator -D ${dir} --backoffRNGSeed ${rng} --doNotUseNeighboursList #&> /dev/null  
	    fi
	    awk '$1 == "1" &&  $6=="1003"'  ${dir}/events.log > ${dir}/receivedata.log
	    awk '$1 == "0" &&  $7=="1003"'  ${dir}/events.log > ${dir}/senddata.log
	    awk '$1 == "0"'  ${dir}/events.log > ${dir}/allsend.log
	    rm ${dir}/events.log
	done
	#endpar
    done
done
#waitpar


for scen in perfectring; do
    for par in Pure_PerfectRing SLR_PerfectRing SLR_NoRing Pure_Ring SLR_Ring; do
	if [ $par = "SLR_PerfectRing" ] || [ $par = "SLR_NoRing" ] || [ $par = "SLR_Ring" ]
	then
	    echo "seed packet_sequence_number sending_nodes_per_packet destination_reached" > ${scen}/${par}/results.txt
	else
	    echo "seed packet_sequence_number sending_nodes_per_packet receiving_nodes_per_packet" > ${scen}/${par}/results.txt
	fi
	#beginpar
	for rng in `seq 0 9`; do
	    dir="${scen}/${par}/run${rng}"
	    for p in `seq 0 49` #change depending on number of packets
	    do
		send=`awk -v P="$p" '$10==P' ${dir}/senddata.log | sort -k3,3 -u | wc -l`
		#sendt=`awk -v P="$p" '$3 == "2" &&  $9==P' ${dir}/senddata.log | awk 'NR==1{print $2; exit}'`
		if [ $par = "SLR_NoRing" ] || [ $par = "SLR_PerfectRing" ] || [ $par = "SLR_Ring" ]
		then
		    receive=`awk -v P="$p" '$3=="3" &&  $8==P' ${dir}/receivedata.log | sort -k3,3 -u | wc -l`
		    #receivet=`awk -v P="$p" '$3=="3" &&  $8==P' ${dir}/receivedata.log | sort -k3,3 -u | sort -k2,2 | awk 'END{print $2; exit}'`
		else
		    receive=`awk -v P="$p" '$8==P' ${dir}/receivedata.log | sort -k3,3 -u | wc -l`
		    #receivet=`awk -v P="$p" '$8==P' ${dir}/receivedata.log | sort -k3,3 -u | sort -k2,2 | awk 'END{print $2; exit}'`
		fi
		echo ${rng} ${p} ${send} ${receive} >>  ${scen}/${par}/results.txt
	    done
	done
	awk1=`awk '{s+=$3} END{print s/(NR - 1)}'  ${scen}/${par}/results.txt`
	awk2=`awk '{t+=$4} END{print t/(NR - 1)}'  ${scen}/${par}/results.txt`
	echo average number of forwarders, number of receivers respectively: ${awk1} ${awk2} >>  ${scen}/${par}/finalresults.txt
	#endpar
    done
done
#waitpar
